@@ -791,7 +791,7 @@ class Coco:
         self.images.append(image)
 
     @classmethod
-    def from_coco_dict_or_path(cls, coco_dict_or_path, desired_name2id=None, remapping_dict=None):
+    def from_coco_dict_or_path(cls, coco_dict_or_path, desired_name2id=None, remapping_dict=None, mp=False):
         """
         Creates coco object from COCO formatted dict or COCO dataset file path.
 
@@ -803,6 +803,9 @@ class Coco:
                 {"human": 1, "car": 2, "big_vehicle": 3}
             remapping_dict: dict
                 {1:0, 2:1} maps category id 1 to 0 and category id 2 to 1
+            mp: bool
+                If True, multiprocess mode is on.
+                Should be called in 'if __name__ == __main__:' block.
 
         Properties:
             images: list of CocoImage
@@ -834,7 +837,10 @@ class Coco:
 
         # arrange image id to annotation id mapping
         coco.add_categories_from_coco_category_list(coco_dict["categories"])
-        imageid2annotationlist = get_imageid2annotationlist_mapping_mt(coco_dict)
+        if mp:
+            imageid2annotationlist = get_imageid2annotationlist_mapping_mp(coco_dict)
+        else:
+            imageid2annotationlist = get_imageid2annotationlist_mapping(coco_dict)
         category_mapping = coco.category_mapping
 
         coco_image_list = []
@@ -875,10 +881,6 @@ class Coco:
             category_mapping[category.id] = category.name
         return category_mapping
 
-    @property
-    def imageid2annotationlist(self):
-        return get_imageid2annotationlist_mapping_mt(self.json)
-
     @property
     def json(self):
         return create_coco_dict(
@@ -888,14 +890,12 @@ class Coco:
         )
 
     def split_coco_as_train_val(
-        self, file_name=None, target_dir=None, train_split_rate=0.9, numpy_seed=0
+        self, train_split_rate=0.9, numpy_seed=0
     ):
         """
-        Split images into train-val and saves as seperate coco dataset files.
+        Split images into train-val and returns them as sahi.utils.coco.Coco objects.
 
         Args:
-            file_name: str
-            target_dir: str
             train_split_rate: float
             numpy_seed: int
                 To fix the numpy seed.
@@ -903,21 +903,13 @@ class Coco:
         Returns:
             result : dict
                 {
-                    "train_dict": "",
-                    "val_dict": "",
-                    "train_path": "",
-                    "val_path": "",
+                    "train_coco": "",
+                    "val_coco": "",
                 }
         """
         # fix numpy numpy seed
         np.random.seed(numpy_seed)
 
-        # set output coco file name
-        if file_name:
-            None
-        elif target_dir:
-            raise ValueError("file_name should be specified.")
-
         # divide images
         num_images = len(self.images)
         shuffled_images = copy.deepcopy(self.images)
@@ -926,36 +918,20 @@ class Coco:
         train_images = shuffled_images[:num_train]
         val_images = shuffled_images[num_train:]
 
-        # form train val coco dicts
-        train_coco_dict = create_coco_dict(
-            images=train_images,
-            categories=self.json_categories,
-            ignore_negative_samples=False,
-        )
-        val_coco_dict = create_coco_dict(
-            images=val_images,
-            categories=self.json_categories,
-            ignore_negative_samples=False,
-        )
+        # form train val coco objects
+        train_coco = Coco(name=self.name if self.name else "split" + '_train')
+        train_coco.images = train_images
+        train_coco.categories = self.categories
+
+        val_coco = Coco(name=self.name if self.name else "split" + '_val')
+        val_coco.images = val_images
+        val_coco.categories = self.categories
+
         # return result
-        if not target_dir:
-            return {
-                "train_dict": train_coco_dict,
-                "val_dict": val_coco_dict,
-                "train_path": "",
-                "val_path": "",
-            }
-        else:
-            train_coco_dict_path = os.path.join(target_dir, file_name + "_train.json")
-            save_json(train_coco_dict, train_coco_dict_path)
-            val_coco_dict_path = os.path.join(target_dir, file_name + "_val.json")
-            save_json(val_coco_dict, val_coco_dict_path)
-            return {
-                "train_dict": train_coco_dict,
-                "val_dict": val_coco_dict,
-                "train_path": train_coco_dict_path,
-                "val_path": val_coco_dict_path,
-            }
+        return {
+            "train_coco": train_coco,
+            "val_coco": val_coco,
+        }
 
     def export_as_yolov5(self, image_dir, output_dir, train_split_rate=1, numpy_seed=0):
         """
@@ -989,19 +965,17 @@ class Coco:
         # split dataset
         if split_mode == "TRAINVAL":
             result = self.split_coco_as_train_val(
-                file_name=None,
-                target_dir=None,
                 train_split_rate=train_split_rate,
                 numpy_seed=numpy_seed,
             )
-            train_coco_dict = result["train_dict"]
-            val_coco_dict = result["val_dict"]
+            train_coco = result["train_coco"]
+            val_coco = result["val_coco"]
         elif split_mode == "TRAIN":
-            train_coco_dict = self.json
-            val_coco_dict = None
+            train_coco = self
+            val_coco = None
         elif split_mode == "VAL":
-            train_coco_dict = None
-            val_coco_dict = self.json
+            train_coco = None
+            val_coco = self
 
         # create train val image dirs
         train_dir = ""
@@ -1015,12 +989,12 @@ class Coco:
 
         # create image symlinks and annotation txts
         if split_mode in ["TRAINVAL", "TRAIN"]:
-            export_yolov5_images_and_txts_from_coco_dict(
-                image_dir, output_dir=train_dir, coco_dict_or_path=train_coco_dict
+            export_yolov5_images_and_txts_from_coco_object(
+                image_dir, output_dir=train_dir, coco=train_coco
             )
         if split_mode in ["TRAINVAL", "VAL"]:
-            export_yolov5_images_and_txts_from_coco_dict(
-                image_dir, output_dir=val_dir, coco_dict_or_path=val_coco_dict
+            export_yolov5_images_and_txts_from_coco_object(
+                image_dir, output_dir=val_dir, coco=val_coco
             )
 
         # create yolov5 data yaml
@@ -1052,8 +1026,8 @@ class Coco:
         return subsampled_coco
 
 
-def export_yolov5_images_and_txts_from_coco_dict(
-    image_dir, output_dir, coco_dict_or_path
+def export_yolov5_images_and_txts_from_coco_object(
+    image_dir, output_dir, coco
 ):
     """
     Creates image symlinks and annotation txts in yolo format from coco dataset.
@@ -1063,11 +1037,9 @@ def export_yolov5_images_and_txts_from_coco_dict(
             Source image directory that contains coco images.
         output_dir: str
             Export directory.
-        coco_dict_or_path: str or dict
-            Path for the coco dataset file or coco dataset as python dictionary.
+        coco: sahi.utils.coco.Coco
+            Initialized Coco object that contains images and categories.
     """
-    # create coco instance from coco_dict_or_path
-    coco = Coco.from_coco_dict_or_path(coco_dict_or_path)
 
     for image in tqdm(coco.images):
         # Create a symbolic link pointing to src named dst
@@ -1326,9 +1298,9 @@ def get_image_annotations(image_id, annotations):
     return image_id, image_annotations
 
 
-def get_imageid2annotationlist_mapping_mt(coco_dict):
+def get_imageid2annotationlist_mapping_mp(coco_dict):
     """
-    Multithreaded version of sahi.utils.coco.get_imageid2annotationlist_mapping. (3 times faster)
+    Multiprocess version of sahi.utils.coco.get_imageid2annotationlist_mapping. (3 times faster)
     """
     imageid2annotationlist_mapping = {}
     annotations = coco_dict["annotations"]
